# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtlab/ui/peak_ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(579, 449)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame_2 = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setObjectName("frame_2")
        self.treeLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.treeLayout.setContentsMargins(0, 0, 0, 0)
        self.treeLayout.setObjectName("treeLayout")
        self.verticalLayout.addWidget(self.frame_2)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem)
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(self.tab_3)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.typeBox = QtWidgets.QComboBox(self.groupBox)
        self.typeBox.setMinimumSize(QtCore.QSize(200, 0))
        self.typeBox.setObjectName("typeBox")
        self.typeBox.addItem("")
        self.typeBox.addItem("")
        self.verticalLayout_2.addWidget(self.typeBox)
        self.autodetectBox = QtWidgets.QCheckBox(self.groupBox)
        self.autodetectBox.setObjectName("autodetectBox")
        self.verticalLayout_2.addWidget(self.autodetectBox)
        self.horizontalLayout_2.addWidget(self.groupBox)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_3)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.focusBox = QtWidgets.QCheckBox(self.groupBox_4)
        self.focusBox.setChecked(True)
        self.focusBox.setObjectName("focusBox")
        self.gridLayout_4.addWidget(self.focusBox, 0, 0, 1, 1)
        self.focusMinBox = QtWidgets.QSpinBox(self.groupBox_4)
        self.focusMinBox.setMaximum(999999999)
        self.focusMinBox.setProperty("value", 0)
        self.focusMinBox.setObjectName("focusMinBox")
        self.gridLayout_4.addWidget(self.focusMinBox, 0, 1, 1, 1)
        self.focusMaxBox = QtWidgets.QSpinBox(self.groupBox_4)
        self.focusMaxBox.setMaximum(999999999)
        self.focusMaxBox.setProperty("value", 0)
        self.focusMaxBox.setObjectName("focusMaxBox")
        self.gridLayout_4.addWidget(self.focusMaxBox, 0, 2, 1, 1)
        self.statsBox = QtWidgets.QCheckBox(self.groupBox_4)
        self.statsBox.setChecked(True)
        self.statsBox.setObjectName("statsBox")
        self.gridLayout_4.addWidget(self.statsBox, 1, 0, 1, 1)
        self.statsMinBox = QtWidgets.QSpinBox(self.groupBox_4)
        self.statsMinBox.setMaximum(999999999)
        self.statsMinBox.setProperty("value", 0)
        self.statsMinBox.setObjectName("statsMinBox")
        self.gridLayout_4.addWidget(self.statsMinBox, 1, 1, 1, 1)
        self.statsMaxBox = QtWidgets.QSpinBox(self.groupBox_4)
        self.statsMaxBox.setMaximum(999999999)
        self.statsMaxBox.setProperty("value", 0)
        self.statsMaxBox.setObjectName("statsMaxBox")
        self.gridLayout_4.addWidget(self.statsMaxBox, 1, 2, 1, 1)
        self.horizontalLayout_2.addWidget(self.groupBox_4)
        self.tabWidget.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_4)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab_4)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        self.label_2.setObjectName("label_2")
        self.gridLayout_2.addWidget(self.label_2, 1, 0, 1, 1)
        self.yLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.yLine.setObjectName("yLine")
        self.gridLayout_2.addWidget(self.yLine, 1, 1, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_2)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.xLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.xLine.setObjectName("xLine")
        self.gridLayout_2.addWidget(self.xLine, 0, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem2, 2, 0, 1, 1)
        self.horizontalLayout_3.addWidget(self.groupBox_2)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_4)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.yStatsLine = QtWidgets.QLineEdit(self.groupBox_3)
        self.yStatsLine.setObjectName("yStatsLine")
        self.gridLayout_3.addWidget(self.yStatsLine, 2, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_3)
        self.label_4.setObjectName("label_4")
        self.gridLayout_3.addWidget(self.label_4, 2, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_3.addWidget(self.label_3, 1, 0, 1, 1)
        self.xStatsLine = QtWidgets.QLineEdit(self.groupBox_3)
        self.xStatsLine.setObjectName("xStatsLine")
        self.gridLayout_3.addWidget(self.xStatsLine, 1, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        self.label_5.setObjectName("label_5")
        self.gridLayout_3.addWidget(self.label_5, 0, 0, 1, 1)
        self.titleStatsLine = QtWidgets.QLineEdit(self.groupBox_3)
        self.titleStatsLine.setObjectName("titleStatsLine")
        self.gridLayout_3.addWidget(self.titleStatsLine, 0, 1, 1, 1)
        self.horizontalLayout_3.addWidget(self.groupBox_3)
        self.tabWidget.addTab(self.tab_4, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.frame = QtWidgets.QFrame(self.centralwidget)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setObjectName("frame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout.setContentsMargins(-1, 6, -1, -1)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.clearButton = QtWidgets.QPushButton(self.frame)
        self.clearButton.setObjectName("clearButton")
        self.horizontalLayout.addWidget(self.clearButton)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.quitButton = QtWidgets.QPushButton(self.frame)
        self.quitButton.setObjectName("quitButton")
        self.horizontalLayout.addWidget(self.quitButton)
        self.convertButton = QtWidgets.QPushButton(self.frame)
        self.convertButton.setObjectName("convertButton")
        self.horizontalLayout.addWidget(self.convertButton)
        self.verticalLayout.addWidget(self.frame)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusBar = QtWidgets.QStatusBar(MainWindow)
        self.statusBar.setObjectName("statusBar")
        MainWindow.setStatusBar(self.statusBar)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        self.groupBox.setTitle(_translate("MainWindow", "Data type"))
        self.typeBox.setItemText(0, _translate("MainWindow", "Cary WinUV (v3)"))
        self.typeBox.setItemText(1, _translate("MainWindow", "OMNIC for Dispertive Raman (v8)"))
        self.autodetectBox.setText(_translate("MainWindow", "Auto-detect"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Details"))
        self.focusBox.setText(_translate("MainWindow", "Focus"))
        self.statsBox.setText(_translate("MainWindow", "Stats"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Options"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Axis"))
        self.label_2.setText(_translate("MainWindow", "Vertical"))
        self.label.setText(_translate("MainWindow", "Horizontal"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Stats"))
        self.label_4.setText(_translate("MainWindow", "Vertical"))
        self.label_3.setText(_translate("MainWindow", "Horizontal"))
        self.label_5.setText(_translate("MainWindow", "Title"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "Labels"))
        self.clearButton.setText(_translate("MainWindow", "Clear"))
        self.quitButton.setText(_translate("MainWindow", "Quit"))
        self.convertButton.setText(_translate("MainWindow", "Convert"))
