# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtlab/ui/hsp_ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(822, 682)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_7.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setFocusPolicy(QtCore.Qt.TabFocus)
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setDocumentMode(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.frame_6 = QtWidgets.QFrame(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_6.sizePolicy().hasHeightForWidth())
        self.frame_6.setSizePolicy(sizePolicy)
        self.frame_6.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.searchTreeLayout = QtWidgets.QVBoxLayout(self.frame_6)
        self.searchTreeLayout.setObjectName("searchTreeLayout")
        self.horizontalLayout.addWidget(self.frame_6)
        self.frame_8 = QtWidgets.QFrame(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_8.sizePolicy().hasHeightForWidth())
        self.frame_8.setSizePolicy(sizePolicy)
        self.frame_8.setMaximumSize(QtCore.QSize(280, 16777215))
        self.frame_8.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_8.setObjectName("frame_8")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.frame_8)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox_3 = QtWidgets.QGroupBox(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setContentsMargins(0, -1, 0, -1)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupPreferedBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.groupPreferedBox.setFocusPolicy(QtCore.Qt.TabFocus)
        self.groupPreferedBox.setStyleSheet("color: #004000;\n"
"background-color: #c6efce;")
        self.groupPreferedBox.setChecked(True)
        self.groupPreferedBox.setObjectName("groupPreferedBox")
        self.gridLayout_3.addWidget(self.groupPreferedBox, 0, 0, 1, 1)
        self.groupUsableBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.groupUsableBox.setFocusPolicy(QtCore.Qt.TabFocus)
        self.groupUsableBox.setStyleSheet("color: #553400;\n"
"background-color: #ffeb9c;")
        self.groupUsableBox.setObjectName("groupUsableBox")
        self.gridLayout_3.addWidget(self.groupUsableBox, 0, 1, 1, 1)
        self.groupHazardousBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.groupHazardousBox.setStyleSheet("color: #9c0006;\n"
"background-color: #ffc7ce;")
        self.groupHazardousBox.setObjectName("groupHazardousBox")
        self.gridLayout_3.addWidget(self.groupHazardousBox, 1, 0, 1, 1)
        self.groupCustomBox = QtWidgets.QCheckBox(self.groupBox_3)
        self.groupCustomBox.setFocusPolicy(QtCore.Qt.TabFocus)
        self.groupCustomBox.setObjectName("groupCustomBox")
        self.gridLayout_3.addWidget(self.groupCustomBox, 1, 1, 1, 1)
        self.verticalLayout_3.addWidget(self.groupBox_3)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)
        self.groupBox = QtWidgets.QGroupBox(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setContentsMargins(0, -1, 0, -1)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.frame = QtWidgets.QFrame(self.groupBox)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_4.setContentsMargins(-1, 0, -1, 0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.targetS2VolBox = QtWidgets.QSpinBox(self.frame)
        self.targetS2VolBox.setMaximum(100)
        self.targetS2VolBox.setObjectName("targetS2VolBox")
        self.gridLayout_4.addWidget(self.targetS2VolBox, 2, 1, 1, 1)
        self.targetS1VolBox = QtWidgets.QSpinBox(self.frame)
        self.targetS1VolBox.setMaximum(100)
        self.targetS1VolBox.setProperty("value", 100)
        self.targetS1VolBox.setObjectName("targetS1VolBox")
        self.gridLayout_4.addWidget(self.targetS1VolBox, 1, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.frame)
        self.label_2.setObjectName("label_2")
        self.gridLayout_4.addWidget(self.label_2, 0, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.frame)
        self.label_3.setObjectName("label_3")
        self.gridLayout_4.addWidget(self.label_3, 0, 1, 1, 1)
        self.frame_7 = QtWidgets.QFrame(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_7.sizePolicy().hasHeightForWidth())
        self.frame_7.setSizePolicy(sizePolicy)
        self.frame_7.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_7.setObjectName("frame_7")
        self.inputLayout = QtWidgets.QVBoxLayout(self.frame_7)
        self.inputLayout.setContentsMargins(0, 0, 0, 0)
        self.inputLayout.setObjectName("inputLayout")
        self.gridLayout_4.addWidget(self.frame_7, 1, 0, 2, 1)
        self.verticalLayout_2.addWidget(self.frame)
        self.frame_2 = QtWidgets.QFrame(self.groupBox)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout.setObjectName("gridLayout")
        self.dTargetEnableBox = QtWidgets.QCheckBox(self.frame_2)
        self.dTargetEnableBox.setObjectName("dTargetEnableBox")
        self.gridLayout.addWidget(self.dTargetEnableBox, 0, 0, 1, 1)
        self.pTargetEnableBox = QtWidgets.QCheckBox(self.frame_2)
        self.pTargetEnableBox.setObjectName("pTargetEnableBox")
        self.gridLayout.addWidget(self.pTargetEnableBox, 0, 1, 1, 1)
        self.hTargetEnableBox = QtWidgets.QCheckBox(self.frame_2)
        self.hTargetEnableBox.setObjectName("hTargetEnableBox")
        self.gridLayout.addWidget(self.hTargetEnableBox, 0, 2, 1, 1)
        self.dTargetBox = QtWidgets.QDoubleSpinBox(self.frame_2)
        self.dTargetBox.setObjectName("dTargetBox")
        self.gridLayout.addWidget(self.dTargetBox, 1, 0, 1, 1)
        self.pTargetBox = QtWidgets.QDoubleSpinBox(self.frame_2)
        self.pTargetBox.setObjectName("pTargetBox")
        self.gridLayout.addWidget(self.pTargetBox, 1, 1, 1, 1)
        self.hTargetBox = QtWidgets.QDoubleSpinBox(self.frame_2)
        self.hTargetBox.setObjectName("hTargetBox")
        self.gridLayout.addWidget(self.hTargetBox, 1, 2, 1, 1)
        self.verticalLayout_2.addWidget(self.frame_2)
        self.verticalLayout_3.addWidget(self.groupBox)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.frame_8)
        self.groupBox_4.setObjectName("groupBox_4")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.groupBox_4)
        self.horizontalLayout_6.setContentsMargins(0, -1, 0, -1)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.searchAllButton = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.searchAllButton.sizePolicy().hasHeightForWidth())
        self.searchAllButton.setSizePolicy(sizePolicy)
        self.searchAllButton.setObjectName("searchAllButton")
        self.horizontalLayout_6.addWidget(self.searchAllButton)
        self.searchSingleButton = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.searchSingleButton.sizePolicy().hasHeightForWidth())
        self.searchSingleButton.setSizePolicy(sizePolicy)
        self.searchSingleButton.setObjectName("searchSingleButton")
        self.horizontalLayout_6.addWidget(self.searchSingleButton)
        self.searchDualButton = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.searchDualButton.sizePolicy().hasHeightForWidth())
        self.searchDualButton.setSizePolicy(sizePolicy)
        self.searchDualButton.setObjectName("searchDualButton")
        self.horizontalLayout_6.addWidget(self.searchDualButton)
        self.searchTripleButton = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.searchTripleButton.sizePolicy().hasHeightForWidth())
        self.searchTripleButton.setSizePolicy(sizePolicy)
        self.searchTripleButton.setObjectName("searchTripleButton")
        self.horizontalLayout_6.addWidget(self.searchTripleButton)
        self.verticalLayout_3.addWidget(self.groupBox_4)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem2)
        self.groupBox_2 = QtWidgets.QGroupBox(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setContentsMargins(0, -1, 0, -1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.pSelectLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.pSelectLine.setAlignment(QtCore.Qt.AlignCenter)
        self.pSelectLine.setReadOnly(True)
        self.pSelectLine.setObjectName("pSelectLine")
        self.gridLayout_2.addWidget(self.pSelectLine, 2, 2, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.groupBox_2)
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 2, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 0, 2, 1, 1)
        self.dTargetLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.dTargetLine.setAlignment(QtCore.Qt.AlignCenter)
        self.dTargetLine.setReadOnly(True)
        self.dTargetLine.setObjectName("dTargetLine")
        self.gridLayout_2.addWidget(self.dTargetLine, 3, 1, 1, 1)
        self.pDeltaLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.pDeltaLine.setAlignment(QtCore.Qt.AlignCenter)
        self.pDeltaLine.setReadOnly(True)
        self.pDeltaLine.setObjectName("pDeltaLine")
        self.gridLayout_2.addWidget(self.pDeltaLine, 4, 2, 1, 1)
        self.pTargetLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.pTargetLine.setAlignment(QtCore.Qt.AlignCenter)
        self.pTargetLine.setReadOnly(True)
        self.pTargetLine.setObjectName("pTargetLine")
        self.gridLayout_2.addWidget(self.pTargetLine, 3, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_2)
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 3, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.groupBox_2)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 4, 0, 1, 1)
        self.hSelectLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.hSelectLine.setAlignment(QtCore.Qt.AlignCenter)
        self.hSelectLine.setReadOnly(True)
        self.hSelectLine.setObjectName("hSelectLine")
        self.gridLayout_2.addWidget(self.hSelectLine, 2, 3, 1, 1)
        self.hDeltaLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.hDeltaLine.setAlignment(QtCore.Qt.AlignCenter)
        self.hDeltaLine.setReadOnly(True)
        self.hDeltaLine.setObjectName("hDeltaLine")
        self.gridLayout_2.addWidget(self.hDeltaLine, 4, 3, 1, 1)
        self.dDeltaLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.dDeltaLine.setAlignment(QtCore.Qt.AlignCenter)
        self.dDeltaLine.setReadOnly(True)
        self.dDeltaLine.setObjectName("dDeltaLine")
        self.gridLayout_2.addWidget(self.dDeltaLine, 4, 1, 1, 1)
        self.dSelectLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.dSelectLine.setAlignment(QtCore.Qt.AlignCenter)
        self.dSelectLine.setReadOnly(True)
        self.dSelectLine.setObjectName("dSelectLine")
        self.gridLayout_2.addWidget(self.dSelectLine, 2, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_2)
        self.label_9.setObjectName("label_9")
        self.gridLayout_2.addWidget(self.label_9, 3, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setAlignment(QtCore.Qt.AlignCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 0, 1, 1, 1)
        self.hTargetLine = QtWidgets.QLineEdit(self.groupBox_2)
        self.hTargetLine.setAlignment(QtCore.Qt.AlignCenter)
        self.hTargetLine.setReadOnly(True)
        self.hTargetLine.setObjectName("hTargetLine")
        self.gridLayout_2.addWidget(self.hTargetLine, 3, 3, 1, 1)
        self.verticalLayout_3.addWidget(self.groupBox_2)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem3)
        self.groupBox_5 = QtWidgets.QGroupBox(self.frame_8)
        self.groupBox_5.setObjectName("groupBox_5")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_5)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.filterAllBox = QtWidgets.QRadioButton(self.groupBox_5)
        self.filterAllBox.setChecked(True)
        self.filterAllBox.setObjectName("filterAllBox")
        self.horizontalLayout_5.addWidget(self.filterAllBox)
        self.filterSingleBox = QtWidgets.QRadioButton(self.groupBox_5)
        self.filterSingleBox.setObjectName("filterSingleBox")
        self.horizontalLayout_5.addWidget(self.filterSingleBox)
        self.filterDualBox = QtWidgets.QRadioButton(self.groupBox_5)
        self.filterDualBox.setObjectName("filterDualBox")
        self.horizontalLayout_5.addWidget(self.filterDualBox)
        self.filterTripleBox = QtWidgets.QRadioButton(self.groupBox_5)
        self.filterTripleBox.setObjectName("filterTripleBox")
        self.horizontalLayout_5.addWidget(self.filterTripleBox)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem4)
        self.verticalLayout_3.addWidget(self.groupBox_5)
        self.horizontalLayout.addWidget(self.frame_8)
        self.tabWidget.addTab(self.tab, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tab_3)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.frame_3 = QtWidgets.QFrame(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_3.sizePolicy().hasHeightForWidth())
        self.frame_3.setSizePolicy(sizePolicy)
        self.frame_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_3.setObjectName("frame_3")
        self.groupTreeLayout = QtWidgets.QVBoxLayout(self.frame_3)
        self.groupTreeLayout.setObjectName("groupTreeLayout")
        self.horizontalLayout_3.addWidget(self.frame_3)
        self.frame_9 = QtWidgets.QFrame(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_9.sizePolicy().hasHeightForWidth())
        self.frame_9.setSizePolicy(sizePolicy)
        self.frame_9.setMaximumSize(QtCore.QSize(280, 16777215))
        self.frame_9.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_9.setObjectName("frame_9")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_9)
        self.verticalLayout.setContentsMargins(-1, -1, -1, 6)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_6 = QtWidgets.QGroupBox(self.frame_9)
        self.groupBox_6.setObjectName("groupBox_6")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_6)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupPreferedButton = QtWidgets.QRadioButton(self.groupBox_6)
        self.groupPreferedButton.setStyleSheet("color: #004000;\n"
"background-color: #c6efce;")
        self.groupPreferedButton.setChecked(True)
        self.groupPreferedButton.setObjectName("groupPreferedButton")
        self.gridLayout_6.addWidget(self.groupPreferedButton, 0, 0, 1, 1)
        self.groupUsableButton = QtWidgets.QRadioButton(self.groupBox_6)
        self.groupUsableButton.setStyleSheet("color: #553400;\n"
"background-color: #ffeb9c;")
        self.groupUsableButton.setObjectName("groupUsableButton")
        self.gridLayout_6.addWidget(self.groupUsableButton, 0, 1, 1, 1)
        self.groupHazardousButton = QtWidgets.QRadioButton(self.groupBox_6)
        self.groupHazardousButton.setStyleSheet("color: #9c0006;\n"
"background-color: #ffc7ce;")
        self.groupHazardousButton.setObjectName("groupHazardousButton")
        self.gridLayout_6.addWidget(self.groupHazardousButton, 1, 0, 1, 1)
        self.groupCustomButton = QtWidgets.QRadioButton(self.groupBox_6)
        self.groupCustomButton.setObjectName("groupCustomButton")
        self.gridLayout_6.addWidget(self.groupCustomButton, 1, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox_6)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem5)
        self.groupBox_7 = QtWidgets.QGroupBox(self.frame_9)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label = QtWidgets.QLabel(self.groupBox_7)
        self.label.setObjectName("label")
        self.gridLayout_5.addWidget(self.label, 4, 0, 1, 1)
        self.groupNameLine = QtWidgets.QLineEdit(self.groupBox_7)
        self.groupNameLine.setObjectName("groupNameLine")
        self.gridLayout_5.addWidget(self.groupNameLine, 1, 0, 1, 7)
        self.label_11 = QtWidgets.QLabel(self.groupBox_7)
        self.label_11.setObjectName("label_11")
        self.gridLayout_5.addWidget(self.label_11, 3, 0, 1, 1)
        self.hGroupBox = QtWidgets.QDoubleSpinBox(self.groupBox_7)
        self.hGroupBox.setObjectName("hGroupBox")
        self.gridLayout_5.addWidget(self.hGroupBox, 4, 1, 1, 1)
        self.dGroupBox = QtWidgets.QDoubleSpinBox(self.groupBox_7)
        self.dGroupBox.setObjectName("dGroupBox")
        self.gridLayout_5.addWidget(self.dGroupBox, 3, 1, 1, 1)
        self.pGroupBox = QtWidgets.QDoubleSpinBox(self.groupBox_7)
        self.pGroupBox.setObjectName("pGroupBox")
        self.gridLayout_5.addWidget(self.pGroupBox, 3, 4, 1, 1)
        self.mvGroupBox = QtWidgets.QDoubleSpinBox(self.groupBox_7)
        self.mvGroupBox.setObjectName("mvGroupBox")
        self.gridLayout_5.addWidget(self.mvGroupBox, 4, 4, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout_5.addItem(spacerItem6, 6, 0, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_7)
        self.label_10.setObjectName("label_10")
        self.gridLayout_5.addWidget(self.label_10, 3, 3, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_7)
        self.label_12.setObjectName("label_12")
        self.gridLayout_5.addWidget(self.label_12, 4, 3, 1, 1)
        self.groupAddButton = QtWidgets.QPushButton(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupAddButton.sizePolicy().hasHeightForWidth())
        self.groupAddButton.setSizePolicy(sizePolicy)
        self.groupAddButton.setMaximumSize(QtCore.QSize(160, 16777215))
        self.groupAddButton.setObjectName("groupAddButton")
        self.gridLayout_5.addWidget(self.groupAddButton, 7, 0, 1, 2)
        self.groupClearButton = QtWidgets.QPushButton(self.groupBox_7)
        self.groupClearButton.setObjectName("groupClearButton")
        self.gridLayout_5.addWidget(self.groupClearButton, 7, 3, 1, 2)
        self.verticalLayout.addWidget(self.groupBox_7)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem7)
        self.frame_4 = QtWidgets.QFrame(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_4.sizePolicy().hasHeightForWidth())
        self.frame_4.setSizePolicy(sizePolicy)
        self.frame_4.setObjectName("frame_4")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.frame_4)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem8)
        self.resetButton = QtWidgets.QPushButton(self.frame_4)
        self.resetButton.setObjectName("resetButton")
        self.horizontalLayout_2.addWidget(self.resetButton)
        self.verticalLayout.addWidget(self.frame_4)
        self.horizontalLayout_3.addWidget(self.frame_9)
        self.tabWidget.addTab(self.tab_3, "")
        self.verticalLayout_7.addWidget(self.tabWidget)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.tabWidget, self.dSelectLine)
        MainWindow.setTabOrder(self.dSelectLine, self.pSelectLine)
        MainWindow.setTabOrder(self.pSelectLine, self.hSelectLine)
        MainWindow.setTabOrder(self.hSelectLine, self.dDeltaLine)
        MainWindow.setTabOrder(self.dDeltaLine, self.pDeltaLine)
        MainWindow.setTabOrder(self.pDeltaLine, self.hDeltaLine)
        MainWindow.setTabOrder(self.hDeltaLine, self.groupPreferedBox)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Solvents groups"))
        self.groupPreferedBox.setText(_translate("MainWindow", "Preferred"))
        self.groupUsableBox.setText(_translate("MainWindow", "Usable"))
        self.groupHazardousBox.setText(_translate("MainWindow", "Hazardous"))
        self.groupCustomBox.setText(_translate("MainWindow", "Custom"))
        self.groupBox.setTitle(_translate("MainWindow", "Target"))
        self.label_2.setText(_translate("MainWindow", "Solvent(s)"))
        self.label_3.setText(_translate("MainWindow", "% Vol."))
        self.dTargetEnableBox.setText(_translate("MainWindow", "𝛿D"))
        self.pTargetEnableBox.setText(_translate("MainWindow", "𝛿P"))
        self.hTargetEnableBox.setText(_translate("MainWindow", "𝛿H"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Search"))
        self.searchAllButton.setText(_translate("MainWindow", "Optimize"))
        self.searchSingleButton.setText(_translate("MainWindow", "1"))
        self.searchDualButton.setText(_translate("MainWindow", "2"))
        self.searchTripleButton.setText(_translate("MainWindow", "3"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Selection"))
        self.label_7.setText(_translate("MainWindow", "Current"))
        self.label_4.setText(_translate("MainWindow", "𝛿P"))
        self.label_5.setText(_translate("MainWindow", "𝛿H"))
        self.label_8.setText(_translate("MainWindow", "Delta"))
        self.label_9.setText(_translate("MainWindow", "Target"))
        self.label_6.setText(_translate("MainWindow", "𝛿D"))
        self.groupBox_5.setTitle(_translate("MainWindow", "Filter view"))
        self.filterAllBox.setText(_translate("MainWindow", "All"))
        self.filterSingleBox.setText(_translate("MainWindow", "Single"))
        self.filterDualBox.setText(_translate("MainWindow", "Dual"))
        self.filterTripleBox.setText(_translate("MainWindow", "Triple"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Search results"))
        self.groupBox_6.setTitle(_translate("MainWindow", "Current Group"))
        self.groupPreferedButton.setText(_translate("MainWindow", "Preferred"))
        self.groupUsableButton.setText(_translate("MainWindow", "Usable"))
        self.groupHazardousButton.setText(_translate("MainWindow", "Hazardous"))
        self.groupCustomButton.setText(_translate("MainWindow", "Custom"))
        self.groupBox_7.setTitle(_translate("MainWindow", "New Solvent"))
        self.label.setText(_translate("MainWindow", "𝛿H"))
        self.groupNameLine.setPlaceholderText(_translate("MainWindow", "Name"))
        self.label_11.setText(_translate("MainWindow", "𝛿D"))
        self.label_10.setText(_translate("MainWindow", "𝛿P"))
        self.label_12.setText(_translate("MainWindow", "MV"))
        self.groupAddButton.setText(_translate("MainWindow", "Add"))
        self.groupClearButton.setText(_translate("MainWindow", "Clear"))
        self.resetButton.setText(_translate("MainWindow", "Reset to default"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Manage groups"))
