# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qtlab/ui/calc_ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(427, 266)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(15, 15, 15, 5)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setFocusPolicy(QtCore.Qt.NoFocus)
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setDocumentMode(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_2.setContentsMargins(15, 15, 15, 15)
        self.gridLayout_2.setHorizontalSpacing(10)
        self.gridLayout_2.setVerticalSpacing(8)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.line_2 = QtWidgets.QFrame(self.tab_3)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setObjectName("line_2")
        self.gridLayout_2.addWidget(self.line_2, 6, 0, 1, 5)
        self.label_20 = QtWidgets.QLabel(self.tab_3)
        self.label_20.setObjectName("label_20")
        self.gridLayout_2.addWidget(self.label_20, 0, 0, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.tab_3)
        self.label_17.setObjectName("label_17")
        self.gridLayout_2.addWidget(self.label_17, 4, 0, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.tab_3)
        self.label_18.setObjectName("label_18")
        self.gridLayout_2.addWidget(self.label_18, 5, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.tab_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 7, 0, 1, 1)
        self.molConcCombo = QtWidgets.QComboBox(self.tab_3)
        self.molConcCombo.setObjectName("molConcCombo")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.molConcCombo.addItem("")
        self.gridLayout_2.addWidget(self.molConcCombo, 4, 2, 1, 3)
        self.label_19 = QtWidgets.QLabel(self.tab_3)
        self.label_19.setObjectName("label_19")
        self.gridLayout_2.addWidget(self.label_19, 1, 0, 1, 1)
        self.molMWBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molMWBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molMWBox.setDecimals(4)
        self.molMWBox.setMaximum(9999999.0)
        self.molMWBox.setObjectName("molMWBox")
        self.gridLayout_2.addWidget(self.molMWBox, 1, 1, 1, 1)
        self.line_4 = QtWidgets.QFrame(self.tab_3)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setObjectName("line_4")
        self.gridLayout_2.addWidget(self.line_4, 2, 0, 1, 5)
        self.label_5 = QtWidgets.QLabel(self.tab_3)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 7, 2, 1, 1)
        self.molVolCombo = QtWidgets.QComboBox(self.tab_3)
        self.molVolCombo.setObjectName("molVolCombo")
        self.molVolCombo.addItem("")
        self.molVolCombo.addItem("")
        self.molVolCombo.addItem("")
        self.gridLayout_2.addWidget(self.molVolCombo, 5, 2, 1, 3)
        self.molResultBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molResultBox.setReadOnly(True)
        self.molResultBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molResultBox.setDecimals(4)
        self.molResultBox.setMaximum(9999999.0)
        self.molResultBox.setObjectName("molResultBox")
        self.gridLayout_2.addWidget(self.molResultBox, 7, 1, 1, 1)
        self.molClearButton = QtWidgets.QToolButton(self.tab_3)
        self.molClearButton.setAutoRaise(True)
        self.molClearButton.setObjectName("molClearButton")
        self.gridLayout_2.addWidget(self.molClearButton, 7, 4, 1, 1)
        self.molCopyButton = QtWidgets.QToolButton(self.tab_3)
        self.molCopyButton.setAutoRaise(True)
        self.molCopyButton.setObjectName("molCopyButton")
        self.gridLayout_2.addWidget(self.molCopyButton, 7, 3, 1, 1)
        self.frame = QtWidgets.QFrame(self.tab_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setObjectName("frame")
        self.molInputLayout = QtWidgets.QHBoxLayout(self.frame)
        self.molInputLayout.setContentsMargins(0, 0, 0, 0)
        self.molInputLayout.setObjectName("molInputLayout")
        self.gridLayout_2.addWidget(self.frame, 0, 1, 1, 3)
        self.molDbAddButton = QtWidgets.QToolButton(self.tab_3)
        self.molDbAddButton.setAutoRaise(True)
        self.molDbAddButton.setObjectName("molDbAddButton")
        self.gridLayout_2.addWidget(self.molDbAddButton, 0, 4, 1, 1)
        self.molDbDelButton = QtWidgets.QToolButton(self.tab_3)
        self.molDbDelButton.setAutoRaise(True)
        self.molDbDelButton.setObjectName("molDbDelButton")
        self.gridLayout_2.addWidget(self.molDbDelButton, 1, 4, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.tab_3)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 2, 1, 2)
        self.molConcBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molConcBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molConcBox.setMaximum(9999999.0)
        self.molConcBox.setObjectName("molConcBox")
        self.gridLayout_2.addWidget(self.molConcBox, 4, 1, 1, 1)
        self.molVolBox = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.molVolBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.molVolBox.setMaximum(9999999.0)
        self.molVolBox.setObjectName("molVolBox")
        self.gridLayout_2.addWidget(self.molVolBox, 5, 1, 1, 1)
        self.tabWidget.addTab(self.tab_3, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_3.setContentsMargins(15, 15, 15, 15)
        self.gridLayout_3.setHorizontalSpacing(10)
        self.gridLayout_3.setVerticalSpacing(8)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.dilResultBox = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilResultBox.setReadOnly(True)
        self.dilResultBox.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilResultBox.setMaximum(9999999.0)
        self.dilResultBox.setObjectName("dilResultBox")
        self.gridLayout_3.addWidget(self.dilResultBox, 7, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.gridLayout_3.addWidget(self.label_10, 5, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.tab)
        self.line.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setObjectName("line")
        self.gridLayout_3.addWidget(self.line, 2, 0, 1, 5)
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 7, 0, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setItalic(False)
        self.label_22.setFont(font)
        self.label_22.setObjectName("label_22")
        self.gridLayout_3.addWidget(self.label_22, 0, 0, 1, 1)
        self.dilV2Combo = QtWidgets.QComboBox(self.tab)
        self.dilV2Combo.setObjectName("dilV2Combo")
        self.dilV2Combo.addItem("")
        self.dilV2Combo.addItem("")
        self.dilV2Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilV2Combo, 5, 2, 1, 3)
        self.dilC2Combo = QtWidgets.QComboBox(self.tab)
        self.dilC2Combo.setObjectName("dilC2Combo")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.dilC2Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilC2Combo, 4, 2, 1, 3)
        self.label_16 = QtWidgets.QLabel(self.tab)
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 4, 0, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.tab)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Plain)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setObjectName("line_3")
        self.gridLayout_3.addWidget(self.line_3, 6, 0, 1, 5)
        self.dilC1Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilC1Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilC1Box.setMaximum(9999999.0)
        self.dilC1Box.setObjectName("dilC1Box")
        self.gridLayout_3.addWidget(self.dilC1Box, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.tab)
        self.label_6.setObjectName("label_6")
        self.gridLayout_3.addWidget(self.label_6, 1, 0, 1, 1)
        self.dilClearButton = QtWidgets.QToolButton(self.tab)
        self.dilClearButton.setAutoRaise(True)
        self.dilClearButton.setObjectName("dilClearButton")
        self.gridLayout_3.addWidget(self.dilClearButton, 7, 4, 1, 1)
        self.dilC1Combo = QtWidgets.QComboBox(self.tab)
        self.dilC1Combo.setObjectName("dilC1Combo")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.dilC1Combo.addItem("")
        self.gridLayout_3.addWidget(self.dilC1Combo, 1, 2, 1, 2)
        self.frame_2 = QtWidgets.QFrame(self.tab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_2.setObjectName("frame_2")
        self.dilInputLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.dilInputLayout.setContentsMargins(0, 0, 0, 0)
        self.dilInputLayout.setObjectName("dilInputLayout")
        self.gridLayout_3.addWidget(self.frame_2, 0, 1, 1, 3)
        self.dilDbDelButton = QtWidgets.QToolButton(self.tab)
        self.dilDbDelButton.setAutoRaise(True)
        self.dilDbDelButton.setObjectName("dilDbDelButton")
        self.gridLayout_3.addWidget(self.dilDbDelButton, 1, 4, 1, 1)
        self.dilDbAddButton = QtWidgets.QToolButton(self.tab)
        self.dilDbAddButton.setAutoRaise(True)
        self.dilDbAddButton.setObjectName("dilDbAddButton")
        self.gridLayout_3.addWidget(self.dilDbAddButton, 0, 4, 1, 1)
        self.dilC2Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilC2Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilC2Box.setMaximum(9999999.0)
        self.dilC2Box.setObjectName("dilC2Box")
        self.gridLayout_3.addWidget(self.dilC2Box, 4, 1, 1, 1)
        self.dilV2Box = QtWidgets.QDoubleSpinBox(self.tab)
        self.dilV2Box.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.dilV2Box.setMaximum(9999999.0)
        self.dilV2Box.setObjectName("dilV2Box")
        self.gridLayout_3.addWidget(self.dilV2Box, 5, 1, 1, 1)
        self.dilResultCombo = QtWidgets.QComboBox(self.tab)
        self.dilResultCombo.setObjectName("dilResultCombo")
        self.dilResultCombo.addItem("")
        self.dilResultCombo.addItem("")
        self.dilResultCombo.addItem("")
        self.gridLayout_3.addWidget(self.dilResultCombo, 7, 2, 1, 2)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.notes = QtWidgets.QPlainTextEdit(self.tab_2)
        self.notes.setObjectName("notes")
        self.horizontalLayout.addWidget(self.notes)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab_4)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.displayFormulaBox = QtWidgets.QCheckBox(self.tab_4)
        self.displayFormulaBox.setObjectName("displayFormulaBox")
        self.verticalLayout_2.addWidget(self.displayFormulaBox)
        self.escapeKeyBox = QtWidgets.QCheckBox(self.tab_4)
        self.escapeKeyBox.setObjectName("escapeKeyBox")
        self.verticalLayout_2.addWidget(self.escapeKeyBox)
        self.copyClipboardBox = QtWidgets.QCheckBox(self.tab_4)
        self.copyClipboardBox.setObjectName("copyClipboardBox")
        self.verticalLayout_2.addWidget(self.copyClipboardBox)
        self.copyNotesBox = QtWidgets.QCheckBox(self.tab_4)
        self.copyNotesBox.setObjectName("copyNotesBox")
        self.verticalLayout_2.addWidget(self.copyNotesBox)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.resetButton = QtWidgets.QPushButton(self.tab_4)
        self.resetButton.setMaximumSize(QtCore.QSize(150, 16777215))
        self.resetButton.setObjectName("resetButton")
        self.verticalLayout_2.addWidget(self.resetButton)
        self.tabWidget.addTab(self.tab_4, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.frame_3 = QtWidgets.QFrame(self.centralwidget)
        self.frame_3.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_3.setObjectName("frame_3")
        self.bottomLayout = QtWidgets.QHBoxLayout(self.frame_3)
        self.bottomLayout.setContentsMargins(0, 0, 0, 0)
        self.bottomLayout.setObjectName("bottomLayout")
        self.statusLabel = QtWidgets.QLabel(self.frame_3)
        self.statusLabel.setText("")
        self.statusLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.statusLabel.setObjectName("statusLabel")
        self.bottomLayout.addWidget(self.statusLabel)
        self.verticalLayout.addWidget(self.frame_3)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.molMWBox, self.molConcBox)
        MainWindow.setTabOrder(self.molConcBox, self.molVolBox)
        MainWindow.setTabOrder(self.molVolBox, self.molResultBox)
        MainWindow.setTabOrder(self.molResultBox, self.molConcCombo)
        MainWindow.setTabOrder(self.molConcCombo, self.molVolCombo)
        MainWindow.setTabOrder(self.molVolCombo, self.dilC1Box)
        MainWindow.setTabOrder(self.dilC1Box, self.dilC2Box)
        MainWindow.setTabOrder(self.dilC2Box, self.dilV2Box)
        MainWindow.setTabOrder(self.dilV2Box, self.dilResultBox)
        MainWindow.setTabOrder(self.dilResultBox, self.dilC1Combo)
        MainWindow.setTabOrder(self.dilC1Combo, self.dilC2Combo)
        MainWindow.setTabOrder(self.dilC2Combo, self.dilV2Combo)
        MainWindow.setTabOrder(self.dilV2Combo, self.notes)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label_20.setText(_translate("MainWindow", "Reagent name"))
        self.label_17.setText(_translate("MainWindow", "Final concentration"))
        self.label_18.setText(_translate("MainWindow", "Final volume"))
        self.label_3.setText(_translate("MainWindow", "Required mass :"))
        self.molConcCombo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.molConcCombo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.molConcCombo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.molConcCombo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.molConcCombo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.label_19.setText(_translate("MainWindow", "Molecular weight"))
        self.label_5.setText(_translate("MainWindow", "g"))
        self.molVolCombo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.molVolCombo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.molVolCombo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.molClearButton.setToolTip(_translate("MainWindow", "Clear all fields"))
        self.molClearButton.setText(_translate("MainWindow", "..."))
        self.molCopyButton.setToolTip(_translate("MainWindow", "Copy"))
        self.molCopyButton.setText(_translate("MainWindow", "..."))
        self.molDbAddButton.setToolTip(_translate("MainWindow", "Save to database"))
        self.molDbAddButton.setText(_translate("MainWindow", "..."))
        self.molDbDelButton.setToolTip(_translate("MainWindow", "Delete from database"))
        self.molDbDelButton.setText(_translate("MainWindow", "..."))
        self.label_4.setText(_translate("MainWindow", "g / mol"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("MainWindow", "Molar solution"))
        self.label_10.setText(_translate("MainWindow", "Final volume"))
        self.label.setText(_translate("MainWindow", "Required volume :"))
        self.label_22.setText(_translate("MainWindow", "Solution name"))
        self.dilV2Combo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.dilV2Combo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.dilV2Combo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.dilC2Combo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.dilC2Combo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.dilC2Combo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.dilC2Combo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.dilC2Combo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.label_16.setText(_translate("MainWindow", "Final concentration"))
        self.label_6.setText(_translate("MainWindow", "Stock concentration"))
        self.dilClearButton.setToolTip(_translate("MainWindow", "Clear all fields"))
        self.dilClearButton.setText(_translate("MainWindow", "..."))
        self.dilC1Combo.setItemText(0, _translate("MainWindow", "molar (M)"))
        self.dilC1Combo.setItemText(1, _translate("MainWindow", "millimolar (mM)"))
        self.dilC1Combo.setItemText(2, _translate("MainWindow", "micromolar (μM)"))
        self.dilC1Combo.setItemText(3, _translate("MainWindow", "nanomolar (nM)"))
        self.dilC1Combo.setItemText(4, _translate("MainWindow", "picomolar (pM)"))
        self.dilDbDelButton.setToolTip(_translate("MainWindow", "Delete from database"))
        self.dilDbDelButton.setText(_translate("MainWindow", "..."))
        self.dilDbAddButton.setToolTip(_translate("MainWindow", "Save to database"))
        self.dilDbAddButton.setText(_translate("MainWindow", "..."))
        self.dilResultCombo.setItemText(0, _translate("MainWindow", "liters (L)"))
        self.dilResultCombo.setItemText(1, _translate("MainWindow", "milliliters (mL)"))
        self.dilResultCombo.setItemText(2, _translate("MainWindow", "microliters (μL)"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "Solution dilution"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("MainWindow", "Notes"))
        self.displayFormulaBox.setText(_translate("MainWindow", "Display current formula"))
        self.escapeKeyBox.setText(_translate("MainWindow", "Quit with escape key"))
        self.copyClipboardBox.setText(_translate("MainWindow", "Copy to clipboard"))
        self.copyNotesBox.setText(_translate("MainWindow", "Copy to notes"))
        self.resetButton.setText(_translate("MainWindow", "Reset to default"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), _translate("MainWindow", "Settings"))
